@@ -20,6 +20,32 @@
 #' @importFrom Rcpp sourceCpp
 NULL
 
+
+#' rpacontrol: Controls the Preferential Attachment (PA) Network Generation
+#' Process
+#'
+#' The \code{rpacontrol} object is designed to control the Preferential
+#' Attachment (PA) network generation process within the \code{rpanet()}
+#' function. It can have the following components:
+#' \itemize{
+#' \item \code{scenario}: controls the edge scenarios
+#' at each step. For more information, please refer to
+#' \code{rpa_control_scenario()}.
+#' \item \code{edgeweight}: controls the weight of
+#' the edges; see \code{rpa_control_edgeweight()} for details.
+#' \item \code{newedge}: controls the creation of
+#' new edges at each step; see \code{rpa_control_newedge()}
+#' for details.
+#' \item \code{preference}: sets preference functions; see
+#' \code{rpa_control_preference()} for details.
+#' \item \code{reciprocal}: controls the creation of reciprocal
+#' edges; see \code{rpa_control_reciprocal()} for details.
+#' }
+#' @name rpacontrol
+#' 
+NULL
+
+
 #' Add components to the control list
 #'
 #' `+` is used to combine components to control the PA network generation
@@ -37,17 +63,24 @@ NULL
 #' @examples
 #' \donttest{
 #' control <- rpa_control_scenario(alpha = 0.5, beta = 0.5) +
-#'     rpa_control_preference(ftype = "customized",
+#'   rpa_control_preference(
+#'     ftype = "customized",
 #'     spref = "pow(outs, 2) + 1",
-#'     tpref = "pow(ins, 2) + 1")
+#'     tpref = "pow(ins, 2) + 1"
+#'   )
 #' }
 #'
 #' control <- rpa_control_scenario(alpha = 1) +
-#'     rpa_control_edgeweight(distribution = rgamma,
-#'         dparams = list(shape = 5, scale = 0.2),
-#'         shift = 1)
+#'   rpa_control_edgeweight(
+#'     distribution = rgamma,
+#'     dparams = list(shape = 5, scale = 0.2),
+#'     shift = 1
+#'   )
 "+.rpacontrol" <- function(e1, e2) {
-  e1 <- structure(utils::modifyList(e1, e2, keep.null = TRUE), class = "rpacontrol")
+  e1 <- structure(
+    utils::modifyList(e1, e2, keep.null = TRUE),
+    class = "rpacontrol"
+  )
   if (is.list(e2$edgeweight$dparams)) {
     e1$edgeweight$dparams <- e2$edgeweight$dparams
   }
@@ -66,8 +99,8 @@ NULL
 #'   node.
 #' @param xi Probability of adding an edge between two new nodes.
 #' @param rho Probability of adding a new node with a self-loop.
-#' @param beta.loop Logical, whether self-loops are allowed under beta scenario.
-#'   Default value is \code{TRUE}.
+#' @param beta.loop Logical. Determines whether self-loops are allowed under the
+#'   beta scenario. Default value is \code{TRUE}.
 #' @param source.first Logical. Defined for \code{beta} scenario edges of
 #'   directed networks. If \code{TRUE}, the source node of a new edge is sampled
 #'   from existing nodes before the target node is sampled; if \code{FALSE}, the
@@ -83,29 +116,35 @@ NULL
 #' @examples
 #' control <- rpa_control_scenario(alpha = 0.5, beta = 0.5, beta.loop = FALSE)
 #' 
-rpa_control_scenario <- function(alpha = 1, beta = 0, gamma = 0, xi = 0, rho = 0,
-                            beta.loop = TRUE, source.first = TRUE) {
-  stopifnot('"alpha + beta + gamma + xi + rho" must equal to 1.' =
-              round(alpha + beta + gamma + xi + rho, 10) == 1)
-  scenario <- list("alpha" = alpha, 
-                   "beta" = beta,
-                   "gamma" = gamma, 
-                   "xi" = xi,
-                   "rho" = rho,
-                   "beta.loop" = beta.loop, 
-                   "source.first" = source.first)
+rpa_control_scenario <- function(
+    alpha = 1, beta = 0, gamma = 0, xi = 0, rho = 0,
+    beta.loop = TRUE, source.first = TRUE) {
+  stopifnot(
+    '"alpha + beta + gamma + xi + rho" must be equal to 1.' =
+      round(alpha + beta + gamma + xi + rho, 10) == 1
+  )
+  scenario <- list(
+    "alpha" = alpha,
+    "beta" = beta,
+    "gamma" = gamma,
+    "xi" = xi,
+    "rho" = rho,
+    "beta.loop" = beta.loop,
+    "source.first" = source.first
+  )
   structure(list("scenario" = scenario),
-            class = "rpacontrol")
+    class = "rpacontrol"
+  )
 }
 
 #' Control weight of new edges. Defined for \code{rpanet}.
 #'
 #' @param distribution Distribution for drawing edge weights. Default is
-#'   \code{NA}. If specified, its first argument must be the number of
+#'   \code{NULL}. If specified, its first argument must be the number of
 #'   observations.
-#' @param dparams Additional parameters passed on to \code{distribution}. The
-#'   name of parameters must be specified.
-#' @param shift A constant add to the values sampled from \code{distribution}. 
+#' @param dparams A list of parameters passed on to \code{distribution}. The
+#'   names of parameters must be specified.
+#' @param shift A constant added to the values sampled from \code{distribution}.
 #'   Default value is 1.
 #'
 #' @return A list of class \code{rpacontrol} with components
@@ -116,45 +155,58 @@ rpa_control_scenario <- function(alpha = 1, beta = 0, gamma = 0, xi = 0, rho = 0
 #'
 #' @examples
 #' # Edge weight follows Gamma(5, 0.2).
-#' control <- rpa_control_edgeweight(distribution = rgamma,
-#'     dparams = list(shape = 5, scale = 0.2),
-#'     shift = 0)
+#' control <- rpa_control_edgeweight(
+#'   distribution = rgamma,
+#'   dparams = list(shape = 5, scale = 0.2),
+#'   shift = 0
+#' )
 #'
 #' # Constant edge weight
 #' control <- rpa_control_edgeweight(shift = 2)
 #' 
-rpa_control_edgeweight <- function(distribution = NA,
-                              dparams = list(),
-                              shift = 1) {
-  edgeweight <- list("distribution" = distribution,
-                     "dparams" = dparams,
-                     "shift" = shift)
-  if (length(edgeweight$dparams) > 0) {
-    stopifnot("Please specify the name of distribution parameters." = 
-                all(! is.null(names(edgeweight$dparams))))
-    stopifnot("Please provide the distribution function." = 
-                is.function(distribution))
+rpa_control_edgeweight <- function(
+    distribution = NULL,
+    dparams = NULL,
+    shift = 1) {
+  edgeweight <- list(
+    "distribution" = distribution,
+    "dparams" = dparams,
+    "shift" = shift
+  )
+  if (!is.null(edgeweight$dparams)) {
+    stopifnot(
+      '"dparams" must be a list.' = is.list(edgeweight$dparams)
+    )
+    stopifnot(
+      "Please specify the name of distribution parameters." =
+        all(!is.null(names(edgeweight$dparams)))
+    )
+    stopifnot(
+      "Please provide the distribution function." =
+        is.function(distribution)
+    )
   }
   structure(list("edgeweight" = edgeweight),
-            class = "rpacontrol")
+    class = "rpacontrol"
+  )
 }
 
 #' Control new edges in each step. Defined for \code{rpanet}.
 #'
 #' @param distribution Distribution for drawing number of new edges. Default is
-#'   \code{NA}. If specified, its first argument must be the number of
+#'   \code{NULL}. If specified, its first argument must be the number of
 #'   observations.
-#' @param dparams Additional parameters passed on to \code{distribution}. The
+#' @param dparams A list of parameters passed on to \code{distribution}. The
 #'   name of parameters must be specified.
-#' @param shift A constant add to the values sampled from \code{distribution}.
+#' @param shift A constant added to the values sampled from \code{distribution}.
 #'   Default value is 1.
-#' @param snode.replace Logical, whether the source nodes in the same step
-#'   should be sampled with replacement. Defined for directed networks.
-#' @param tnode.replace Logical, whether the target nodes in the same step
-#'   should be sampled with replacement. Defined for directed networks.
-#' @param node.replace Logical, whether the nodes in the same step should be
-#'   sampled with replacement. Defined for undirected networks. If FALSE,
-#'   self-loops will not be allowed under beta scenario.
+#' @param snode.replace Logical. Determines whether the source nodes in the same
+#'   step should be sampled with replacement. Defined for directed networks.
+#' @param tnode.replace Logical. Determines whether the target nodes in the same
+#'   step should be sampled with replacement. Defined for directed networks.
+#' @param node.replace Logical. Determines whether the nodes in the same step
+#'   should be sampled with replacement. Defined for undirected networks. If
+#'   FALSE, self-loops will not be allowed under beta scenario.
 #'
 #' @return A list of class \code{rpacontrol} with components
 #'   \code{distribution}, \code{dparams}, \code{shift}, \code{snode.replace},
@@ -164,25 +216,35 @@ rpa_control_edgeweight <- function(distribution = NA,
 #' @export
 #'
 #' @examples
-#' control <- rpa_control_newedge(distribution = rpois,
-#'     dparams = list(lambda = 2),
-#'     shift = 1,
-#'     node.replace = FALSE)
-rpa_control_newedge <- function(distribution = NA,
-                           dparams = list(),
-                           shift = 1,
-                           snode.replace = TRUE,
-                           tnode.replace = TRUE,
-                           node.replace = TRUE) {
-  newedge <- list("distribution" = distribution,
-                  "dparams" = dparams,
-                  "shift" = shift,
-                  "snode.replace" = snode.replace,
-                  "tnode.replace" = tnode.replace,
-                  "node.replace" = node.replace)
-  if (length(newedge$dparams) > 0) {
-    stopifnot("Please specify the name of distribution parameters" = 
-                all(! is.null(names(newedge$dparams))))
+#' control <- rpa_control_newedge(
+#'   distribution = rpois,
+#'   dparams = list(lambda = 2),
+#'   shift = 1,
+#'   node.replace = FALSE
+#' )
+rpa_control_newedge <- function(
+    distribution = NULL,
+    dparams = NULL,
+    shift = 1,
+    snode.replace = TRUE,
+    tnode.replace = TRUE,
+    node.replace = TRUE) {
+  newedge <- list(
+    "distribution" = distribution,
+    "dparams" = dparams,
+    "shift" = shift,
+    "snode.replace" = snode.replace,
+    "tnode.replace" = tnode.replace,
+    "node.replace" = node.replace
+  )
+  if (!is.null(newedge$dparams)) {
+    stopifnot(
+      '"dparams" must be a list.' = is.list(newedge$dparams)
+    )
+    stopifnot(
+      "Please specify the names of distribution parameters" =
+        all(!is.null(names(newedge$dparams)))
+    )
   }
   structure(list("newedge" = newedge), class = "rpacontrol")
 }
@@ -192,7 +254,7 @@ rpa_control_newedge <- function(distribution = NA,
 #' @param ftype Preference function type. Either "default" or "customized".
 #'   "customized" preference functions require "binary" or "linear" generation
 #'   methods. If using default preference functions, \code{sparams},
-#'   \code{tparams} and \code{params} must be specified. If using costomized
+#'   \code{tparams} and \code{params} must be specified. If using customized
 #'   preference functions, \code{spref}, \code{tpref} and \code{pref} must be
 #'   specified.
 #' @param sparams A numerical vector of length 5 giving the parameters of the
@@ -221,13 +283,13 @@ rpa_control_newedge <- function(distribution = NA,
 #'   value is \code{"s + 1"}, i.e, node strength + 1.
 #'
 #' @details If choosing customized preference functions, \code{spref},
-#'   \code{tpref} and and \code{pref} will be used and the network generation
-#'   method must be "binary" or "linear". \code{spref} (\code{tpref}) defines the
+#'   \code{tpref} and \code{pref} will be used and the network generation method
+#'   must be "binary" or "linear". \code{spref} (\code{tpref}) defines the
 #'   source (target) preference function, it can be a character expression or an
 #'   object of class \code{XPtr}. \itemize{ \item{Character expression: } {it
-#'   must be an one-line \code{C++} style expression of \code{outs}
+#'   must be a one-line \code{C++} style expression of \code{outs}
 #'   (node out-strength) and
-#'   \code{ins} (node-instrength). For example, \code{"pow(outs, 2) + 1"},
+#'   \code{ins} (node in-strength). For example, \code{"pow(outs, 2) + 1"},
 #'   \code{"pow(outs, 2) + pow(ins, 2) + 1"}, etc. The expression will be used
 #'   to define an \code{XPtr} via \code{RcppXPtrUtils::cppXPtr}. The \code{XPtr}
 #'   will be passed to the network generation function. The expression must not
@@ -242,10 +304,9 @@ rpa_control_newedge <- function(distribution = NA,
 #'   represent node out- and in-strength, respectively.}}
 #'
 #'   \code{pref} is defined analogously. If using character expression, it must
-#'   be a one-line \code{C++} style expression of \code{s} (node strength). 
-#'   If using
-#'   \code{XPtr}, the supplied \code{C++} function takes only one \code{double}
-#'   argument and returns a \code{double}.
+#'   be a one-line \code{C++} style expression of \code{s} (node strength). If
+#'   using \code{XPtr}, the supplied \code{C++} function takes only one
+#'   \code{double} argument and returns a \code{double}.
 #'
 #' @return A list of class \code{rpacontrol} with components \code{ftype},
 #'   \code{sparams}, \code{tparams}, \code{params} or \code{ftype},
@@ -259,51 +320,70 @@ rpa_control_newedge <- function(distribution = NA,
 #' # Set source preference as out-strength^2 + in-strength + 1,
 #' # target preference as out-strength + in-strength^2 + 1.
 #' # 1. use default preference functions
-#' control1 <- rpa_control_preference(ftype = "default",
-#'     sparams = c(1, 2, 1, 1, 1), tparams = c(1, 1, 1, 2, 1))
+#' control1 <- rpa_control_preference(
+#'   ftype = "default",
+#'   sparams = c(1, 2, 1, 1, 1), tparams = c(1, 1, 1, 2, 1)
+#' )
 #' # 2. use character expressions
-#' control2 <- rpa_control_preference(ftype = "customized",
-#'     spref = "pow(outs, 2) + ins + 1", tpref = "outs + pow(ins, 2) + 1")
+#' control2 <- rpa_control_preference(
+#'   ftype = "customized",
+#'   spref = "pow(outs, 2) + ins + 1", tpref = "outs + pow(ins, 2) + 1"
+#' )
 #' # 3. define XPtr's with C++ source code
-#' spref.pointer <- RcppXPtrUtils::cppXPtr(code =
-#'     "double spref(double outs, double ins) {return pow(outs, 2) + ins + 1;}")
-#' tpref.pointer <- RcppXPtrUtils::cppXPtr(code =
-#'     "double tpref(double outs, double ins) {return outs + pow(ins, 2) + 1;}")
-#' control3 <- rpa_control_preference(ftype = "customized",
-#'     spref = spref.pointer,
-#'     tpref = tpref.pointer)
+#' spref.pointer <- RcppXPtrUtils::cppXPtr(
+#'   code =
+#'     "double spref(double outs, double ins) {return pow(outs, 2) + ins + 1;}"
+#' )
+#' tpref.pointer <- RcppXPtrUtils::cppXPtr(
+#'   code =
+#'     "double tpref(double outs, double ins) {return outs + pow(ins, 2) + 1;}"
+#' )
+#' control3 <- rpa_control_preference(
+#'   ftype = "customized",
+#'   spref = spref.pointer,
+#'   tpref = tpref.pointer
+#' )
 #' ret <- rpanet(1e5, control = control3)
 #' }
-rpa_control_preference <- function(ftype = c("default", "customized"),
-                              sparams = c(1, 1, 0, 0, 1),
-                              tparams = c(0, 0, 1, 1, 1),
-                              params = c(1, 1),
-                              spref = "outs + 1",
-                              tpref = "ins + 1",
-                              pref = "s + 1") {
+rpa_control_preference <- function(
+    ftype = c("default", "customized"),
+    sparams = c(1, 1, 0, 0, 1),
+    tparams = c(0, 0, 1, 1, 1),
+    params = c(1, 1),
+    spref = "outs + 1",
+    tpref = "ins + 1",
+    pref = "s + 1") {
   ftype <- match.arg(ftype)
   if (ftype == "default") {
-    stopifnot("Length or type of parameter is not valid" = 
-                all(length(sparams) == 5,
-                    length(tparams) == 5,
-                    length(params) == 2,
-                    is.numeric(sparams), 
-                    is.numeric(tparams),
-                    is.numeric(params)))
-    preference <- list("ftype" = ftype,
-                       "sparams" = sparams,
-                       "tparams" = tparams,
-                       "params" = params)
-  }
-  else {
-    preference <- list("ftype" = ftype,
-                       "spref" = spref,
-                       "tpref" = tpref,
-                       "pref" = pref)
+    stopifnot(
+      "Length or type of parameter is not valid" =
+        all(
+          length(sparams) == 5,
+          length(tparams) == 5,
+          length(params) == 2,
+          is.numeric(sparams),
+          is.numeric(tparams),
+          is.numeric(params)
+        )
+    )
+    preference <- list(
+      "ftype" = ftype,
+      "sparams" = sparams,
+      "tparams" = tparams,
+      "params" = params
+    )
+  } else {
+    preference <- list(
+      "ftype" = ftype,
+      "spref" = spref,
+      "tpref" = tpref,
+      "pref" = pref
+    )
     preference <- compile_pref_func(preference)
   }
   structure(list("preference" = preference),
-            class = "rpacontrol")
+    class = "rpacontrol"
+  )
 }
 
 #' Control reciprocal edges. Defined for \code{rpanet}.
@@ -328,38 +408,91 @@ rpa_control_preference <- function(ftype = c("default", "customized"),
 #' @export
 #'
 #' @examples
-#' control <- rpa_control_reciprocal(group.prob = c(0.4, 0.6),
-#'     recip.prob = matrix(runif(4), ncol = 2))
-rpa_control_reciprocal <- function(group.prob = NA,
-                              recip.prob = NA, 
-                              selfloop.recip = FALSE) {
-  if (! any(is.na(group.prob))) {
-    stopifnot('"group.prob" must sum to 1.' = 
-                round(sum(group.prob), 10) == 1)
-    if (! any(is.na(recip.prob))) {
+#' control <- rpa_control_reciprocal(
+#'   group.prob = c(0.4, 0.6),
+#'   recip.prob = matrix(runif(4), ncol = 2)
+#' )
+rpa_control_reciprocal <- function(
+    group.prob = NULL,
+    recip.prob = NULL,
+    selfloop.recip = FALSE) {
+  if (!is.null(group.prob)) {
+    stopifnot(
+      '"group.prob" must sum to 1.' =
+        round(sum(group.prob), 10) == 1
+    )
+    if (!is.null(recip.prob)) {
       recip.prob <- as.matrix(recip.prob)
-      stopifnot('"recip.prob" or "group.prob" is not valid.' =
-                  length(group.prob) == nrow(recip.prob) &
-                  nrow(recip.prob) == ncol(recip.prob))
-      stopifnot('"recip.prob" is not valid.' =
-                  all(recip.prob >= 0) &
-                  all(recip.prob <= 1))
-      stopifnot('"group.prob" is not valid.' =
-                  round(sum(group.prob), 10) == 1 &
-                  all(group.prob >= 0))
-    }
-    else {
-      stop('"recip.prob" can not be NA when "group.prob" is specified.')
+      stopifnot(
+        '"recip.prob" or "group.prob" is not valid.' =
+          length(group.prob) == nrow(recip.prob) &
+            nrow(recip.prob) == ncol(recip.prob)
+      )
+      stopifnot(
+        '"recip.prob" is not valid.' =
+          all(recip.prob >= 0) &
+            all(recip.prob <= 1)
+      )
+      stopifnot(
+        '"group.prob" is not valid.' =
+          round(sum(group.prob), 10) == 1 &
+            all(group.prob >= 0)
+      )
+    } else {
+      stop('"recip.prob" can not be NULL when "group.prob" is specified.')
     }
   }
-  if (any(is.na(group.prob))) {
-    if (! is.na(recip.prob)) {
+  if (is.null(group.prob)) {
+    if (!is.null(recip.prob)) {
       stop('"group.prob" is not valid.')
     }
   }
-  reciprocal <- list("group.prob" = group.prob,
-                     "recip.prob" = recip.prob, 
-                     "selfloop.recip" = selfloop.recip)
+  reciprocal <- list(
+    "group.prob" = group.prob,
+    "recip.prob" = recip.prob,
+    "selfloop.recip" = selfloop.recip
+  )
   structure(list("reciprocal" = reciprocal),
-            class = "rpacontrol")
+    class = "rpacontrol"
+  )
+}
+
+#' Default controls for \code{rpanet}
+#'
+#' @return Returns a list of default controls.
+#' @keywords internal
+#'
+rpa_control_default <- function() {
+  rpa_control_scenario() +
+    rpa_control_edgeweight() +
+    rpa_control_newedge() +
+    rpa_control_reciprocal() +
+    rpa_control_preference()
+}
+
+#' Names and descriptions of controls for \code{rpanet()}
+#'
+#' @return Returns a list of control names and descriptions.
+#' @keywords internal
+#' 
+rpa_control_list <- function() {
+  control_names <- c(
+    "scenario",
+    "edgeweight",
+    "newedge",
+    "preference",
+    "reciprocal"
+  )
+
+  control_descriptions <- list(
+    scenario = "Edge scenarios",
+    edgeweight = "Edge weights",
+    newedge = "New edges in each step",
+    preference = "Preference functions",
+    reciprocal = "Reciprocal edges"
+  )
+  return(list(
+    control_names = control_names,
+    control_descriptions = control_descriptions
+  ))
 }
